chisel
======

.. |badge-status| image:: https://img.shields.io/pypi/status/chisel?style=for-the-badge
   :alt: PyPI - Status
   :target: https://pypi.python.org/pypi/chisel/

.. |badge-version| image:: https://img.shields.io/pypi/v/chisel?style=for-the-badge
   :alt: PyPI
   :target: https://pypi.python.org/pypi/chisel/

.. |badge-travis| image:: https://img.shields.io/travis/craigahobbs/chisel?style=for-the-badge
   :alt: Travis (.org)
   :target: https://travis-ci.org/craigahobbs/chisel

.. |badge-codecov| image:: https://img.shields.io/codecov/c/github/craigahobbs/chisel?style=for-the-badge
   :alt: Codecov
   :target: https://codecov.io/gh/craigahobbs/chisel

.. |badge-license| image:: https://img.shields.io/github/license/craigahobbs/chisel?style=for-the-badge
   :alt: GitHub
   :target: https://github.com/craigahobbs/chisel/blob/master/LICENSE

.. |badge-python| image:: https://img.shields.io/pypi/pyversions/chisel?style=for-the-badge
   :alt: PyPI - Python Version
   :target: https://www.python.org/downloads/

|badge-status| |badge-version|

|badge-travis| |badge-codecov|

|badge-license| |badge-python|

Chisel is a light-weight Python WSGI application framework with tools for
building well-documented, well-tested, schema-validated JSON web APIs.  Here are
Chisel's features at a glance:

- Light-weight `WSGI <https://www.python.org/dev/peps/pep-3333/>`_ application framework
- Schema-validated `JSON <https://en.wikipedia.org/wiki/JSON>`_ web APIs
- Schema-level API documentation
- Written in pure `Python <https://python.org>`_
- Zero dependencies
- Python 3.7+

To learn more, proceed to the `Getting Started <https://craigahobbs.github.io/chisel/basics.html>`_ page.


Links
-----

- `Documentation on GitHub Pages <https://craigahobbs.github.io/chisel/>`_
- `Package on pypi <https://pypi.org/project/chisel/>`_
- `Source code on GitHub <https://github.com/craigahobbs/chisel>`_
- `Build on Travis CI <https://travis-ci.org/craigahobbs/chisel>`_
- `Coverage on Codecov <https://codecov.io/gh/craigahobbs/chisel>`_
